@@ -40,7 +40,7 @@ except ImportError:
 
 import numpy as np
 
-from sknano.nanogen import Nanotube, generate_Ch_list, \
+from sknano.structures import Nanotube, generate_Ch_list, \
     generate_Ch_property_grid
 
 from ..tools import get_fpath
@@ -141,7 +141,7 @@ def plot_CNT_Ch_map(args):
     n = np.arange(0, imax + 1, dtype=int)
     m = np.arange(0, imax + 1, dtype=int)
 
-    grid = generate_Ch_property_grid(compute_property=compute_property,
+    grid = generate_Ch_property_grid(compute=compute_property,
                                      imax=imax)
 
     vmin = grid[(grid > -1)].min()
@@ -239,7 +239,7 @@ def plot_CNT_Ch_map(args):
             #        ticklabel = textobj.get_text
 
     if args.overlay_dt_contours:
-        dt_grid = generate_Ch_property_grid(compute_property='dt', imax=imax)
+        dt_grid = generate_Ch_property_grid(compute='dt', imax=imax)
         dt_levels = np.linspace(5, 30, 6, dtype=int)
         #dt_levels = np.linspace(5, 25, 3, dtype=int)
 
