@@ -67,7 +67,7 @@ def plot_argparser():
     plotargs.add_argument('--fname-suffix', default=None,
                           help='append plot file name with this '
                           'suffix (default: %(default)s)')
-    plotargs.add_argument('--frame-legend', action='store_true',
+    plotargs.add_argument('--legend-frameon', action='store_true',
                           help="if True, draw a frame around the legend.")
     plotargs.add_argument('--global-scale-factor', type=float, default=0.5,
                           help='scale plots markers by this factor'
@@ -99,6 +99,10 @@ def plot_argparser():
     plotargs.add_argument('--markevery', type=int, default=1,
                           help='plot marker every multiple of markevery '
                           '(default: %(default)s)')
+    plotargs.add_argument('--ncols', type=int, default=None,
+                          help='number of plot cols (default: %(default)s)')
+    plotargs.add_argument('--nrows', type=int, default=None,
+                          help='number of plot rows (default: %(default)s)')
     plotargs.add_argument('--outpath', default=os.getcwd(),
                           help='output path (default: %(default)s)')
     plotargs.add_argument('--overlay-cfgfile', default=None,
@@ -110,7 +114,7 @@ def plot_argparser():
                           help="amount of padding around the figure when "
                           "``--bbox-inches`` is 'tight' "
                           '(default: %(default)s)')
-    plotargs.add_argument('--plotformat', default='pdf',
+    plotargs.add_argument('--plotformat', default=None,
                           choices=('pdf', 'png', 'jpg', 'ps', 'eps', 'svg'),
                           help='plot output format (default: %(default)s)')
     plotargs.add_argument('--plotcfg', default=None,
@@ -258,6 +262,10 @@ def cmap_argparser():
                                  'bessel', 'mitchell', 'sinc', 'lanczos'),
                         help='interpolation algorithm for image plot '
                         '(default: %(default)s)')
+    parser.add_argument('--ncols', type=int, default=None,
+                        help='number of plot cols (default: %(default)s)')
+    parser.add_argument('--nrows', type=int, default=None,
+                        help='number of plot rows (default: %(default)s)')
     parser.add_argument('--outpath', default=os.getcwd(),
                         help='output path (default: %(default)s)')
     parser.add_argument('--overwrite', action='store_true',
@@ -265,7 +273,7 @@ def cmap_argparser():
     parser.add_argument('--pad-inches', type=float, default=0.1,
                         help="amount of padding around the figure when "
                         "``--bbox-inches`` is 'tight' (default: %(default)s)")
-    parser.add_argument('--plotformat', default='pdf',
+    parser.add_argument('--plotformat', default=None,
                         choices=('pdf', 'png', 'jpg', 'ps', 'eps', 'svg'),
                         help='plot output format (default: %(default)s)')
     parser.add_argument('--plotcfgfile', default=None,
