@@ -17,7 +17,8 @@ import sys
 from collections import deque, OrderedDict
 from pkg_resources import resource_filename
 
-from configobj import ConfigObj
+from configobj import ConfigObj, get_extra_values
+import numpy as np
 
 try:
     from validate import Validator
@@ -28,7 +29,8 @@ except ImportError as e:
           '``pip install --user validate``')
     sys.exit(1)
 
-from ..datautils import DataSet, load_data
+from ..datautils import DataSet, load_data, load_fixed_width_data
+from .._strfuncs import split_replace
 from ._luts import color_dict
 from ._strings import generate_axis_label_dict, plotstr
 
@@ -102,6 +104,7 @@ class PlotConfigParser(object):
 
         self._flattened_datasets = OrderedDict()
         self._flatten_datasets()
+        self._parse_xydata()
 
         if self._args is not None:
             self._check_argparser_overrides()
@@ -125,17 +128,22 @@ class PlotConfigParser(object):
     def _check_argparser_overrides(self):
         if self._args.disable_legend:
             self._plotconfig.disable_legend = True
+        if self._args.legend_frameon:
+            self._plotconfig.legend_frameon = True
+
         if self._args.file_num is not None:
             self._plotconfig.output.file_num = self._args.file_num
         if self._args.fname_prefix is not None:
             self._plotconfig.output.fname_prefix = self._args.fname_prefix
-        if self._args.frame_legend:
-            self._plotconfig.legend_frameon = True
+        if self._args.fname_suffix is not None:
+            self._plotconfig.output.fname_suffix = self._args.fname_suffix
+
         if self._args.overwrite:
             self._plotconfig.output.overwrite = True
-
-        #if self._args.plotformat:
-        #    self_plotconfig.output.plotformat = self._args.plotformat
+        if self._args.plotformat is not None:
+            self._plotconfig.output.plotformat = self._args.plotformat
+        if self._args.save_transparent:
+            self._plotconfig.output.save_transparent = True
 
         if self._args.xlabel is not None:
             self._plotconfig.xaxis.label = self._args.xlabel
@@ -153,8 +161,20 @@ class PlotConfigParser(object):
             if len(dataset_config.sections) == 0:
                 self._datasets.depth = 1
                 ds = DataSet()
-                ds.fname = dataset_config['fname']
-                ds.path = dataset_config['path']
+
+                if dataset_config['axhline']:
+                    ds.axhline = True
+                    ds.ydata = dataset_config['axhline_y']
+                    ds.xdata = 0
+                elif dataset_config['axvline']:
+                    ds.axvline = True
+                    ds.xdata = dataset_config['axhline_x']
+                    ds.ydata = 0
+                else:
+                    ds.dataformat = dataset_config['dataformat']
+                    ds.fname = dataset_config['fname']
+                    ds.path = dataset_config['path']
+
                 self._parse_data(dataset=ds)
                 self._datasets[dataset_id] = ds
             else:
@@ -163,14 +183,31 @@ class PlotConfigParser(object):
                 for subset_id in dataset_config.sections:
                     subset_config = dataset_config[subset_id]
                     subset_ds = DataSet()
-                    subset_ds.fname = subset_config['fname']
-                    if subset_ds.fname is None and \
-                            dataset_config['fname'] is not None:
-                        subset_ds.fname = dataset_config['fname']
-                    subset_ds.path = subset_config['path']
-                    if subset_ds.path is None and \
-                            dataset_config['path'] is not None:
-                        subset_ds.path = dataset_config['path']
+
+                    if subset_config['axhline']:
+                        subset_ds.axhline = True
+                        subset_ds.ydata = subset_config['axhline_y']
+                        subset_ds.xdata = 0
+                    elif subset_config['axvline']:
+                        subset_ds.axvline = True
+                        subset_ds.ydata = 0
+                        subset_ds.xdata = subset_config['axhline_x']
+                    else:
+                        subset_ds.dataformat = subset_config['dataformat']
+                        if subset_ds.dataformat is None and \
+                                dataset_config['dataformat'] is not None:
+                            subset_ds.dataformat = dataset_config['dataformat']
+
+                        subset_ds.fname = subset_config['fname']
+                        if subset_ds.fname is None and \
+                                dataset_config['fname'] is not None:
+                            subset_ds.fname = dataset_config['fname']
+
+                        subset_ds.path = subset_config['path']
+                        if subset_ds.path is None and \
+                                dataset_config['path'] is not None:
+                            subset_ds.path = dataset_config['path']
+
                     self._parse_data(dataset=subset_ds)
                     self._datasets[dataset_id][subset_id] = subset_ds
 
@@ -189,9 +226,13 @@ class PlotConfigParser(object):
                     fpath = os.path.join(dataset.path, dataset.fname)
 
             if fpath is not None:
-                dataset.headers, dataset.data = \
-                    load_data(fpath, headerlines=1,
-                              skip_lines_starting_with='#')
+                if dataset.dataformat in ['textlog', 'txtlog']:
+                    dataset.headers, dataset.data = \
+                        load_fixed_width_data(fpath, comments='--', names=True)
+                else:
+                    dataset.headers, dataset.data = \
+                        load_data(fpath, headerlines=1,
+                                  skip_lines_starting_with='#')
 
     def _parse_plotcfg(self):
         """Parse config file and set attributes of plotconfig object."""
@@ -277,20 +318,19 @@ class PlotConfigParser(object):
                     self._configobj['input_config']['headers'][option])
 
         self._plotconfig.datasets = PlotConfig()
-        datasets_config = self._configobj['datasets']
-        for option in datasets_config.scalars:
+        for option in self._configobj['datasets'].scalars:
             try:
                 setattr(self._plotconfig.datasets, option,
-                        color_dict[datasets_config[option]])
+                        color_dict[self._configobj['datasets'][option]])
             except KeyError:
                 setattr(self._plotconfig.datasets, option,
-                        datasets_config[option])
+                        self._configobj['datasets'][option])
 
         # Parse dataset plotconfig
         for dataset_id, dataset in self._datasets.iteritems():
             setattr(self._plotconfig.datasets, dataset_id, PlotConfig())
             dataset_plotconfig = getattr(self._plotconfig.datasets, dataset_id)
-            dataset_config = datasets_config[dataset_id]
+            dataset_config = self._configobj['datasets'][dataset_id]
             if isinstance(dataset, DataSet):
                 for k, v in dataset_config.iteritems():
                     if v is not None:
@@ -298,13 +338,16 @@ class PlotConfigParser(object):
                             setattr(dataset_plotconfig, k, color_dict[v])
                         except KeyError:
                             setattr(dataset_plotconfig, k, v)
-                    elif k in datasets_config.scalars and \
-                            datasets_config[k] is not None:
+                    elif k in self._configobj['datasets'].scalars and \
+                            self._configobj['datasets'][k] is not None:
                         try:
-                            setattr(dataset_plotconfig, k,
-                                    color_dict[datasets_config[k]])
+                            setattr(
+                                dataset_plotconfig, k,
+                                color_dict[self._configobj['datasets'][k]])
                         except KeyError:
-                            setattr(dataset_plotconfig, k, datasets_config[k])
+                            setattr(
+                                dataset_plotconfig, k,
+                                self._configobj['datasets'][k])
                     elif hasattr(self._plotconfig, k):
                         setattr(dataset_plotconfig, k,
                                 getattr(self._plotconfig, k))
@@ -336,14 +379,15 @@ class PlotConfigParser(object):
                             except KeyError:
                                 setattr(subset_plotconfig, k,
                                         dataset_config[k])
-                        elif k in datasets_config.scalars and \
-                                datasets_config[k] is not None:
+                        elif k in self._configobj['datasets'].scalars and \
+                                self._configobj['datasets'][k] is not None:
                             try:
-                                setattr(subset_plotconfig, k,
-                                        color_dict[datasets_config[k]])
+                                setattr(
+                                    subset_plotconfig, k,
+                                    color_dict[self._configobj['datasets'][k]])
                             except KeyError:
                                 setattr(subset_plotconfig, k,
-                                        datasets_config[k])
+                                        self._configobj['datasets'][k])
                         elif hasattr(self._plotconfig, k):
                             setattr(subset_plotconfig, k,
                                     getattr(self._plotconfig, k))
@@ -357,7 +401,7 @@ class PlotConfigParser(object):
                         else:
                             setattr(subset_plotconfig, k, None)
 
-        self._plotconfig.inset_plotconfig = PlotConfig()
+        #self._plotconfig.inset_plotconfig = PlotConfig()
 
     def _flatten_datasets(self):
         """Generate flattened dataset dictionary."""
@@ -385,12 +429,76 @@ class PlotConfigParser(object):
             self._flattened_datasets[numbered_key] = value
             setattr(self._plotconfig.datasets, numbered_key, attr)
 
+    def _parse_xydata(self):
+        # parse datasets xdata/ydata attributes.
+        # This code needs to be updated to handle multiple xdata/ydata
+        # per dataset.
+        header_xvar = self._plotconfig.input.headers.xvar
+        header_yvar = self._plotconfig.input.headers.yvar
+
+        if header_yvar is not None:
+            for dataset_id, dataset in self._flattened_datasets.iteritems():
+                #dataset_plotconfig = \
+                #    getattr(self._plotconfig.datasets, dataset_id)
+                if dataset.ydata is None:
+                    ydata = None
+                    #if dataset_plotconfig.axhline:
+                    #    ydata = dataset_plotconfig.axhline_y
+                    #elif dataset_plotconfig.axvline:
+                    #    pass
+                    if dataset.dataformat in ('textlog', 'txtlog'):
+                        ydata = dataset.data[split_replace(header_yvar)]
+                    else:
+                        ydata = \
+                            dataset.data[:, dataset.headers.index(header_yvar)]
+
+                    dataset.ydata = ydata
+
+                if dataset.xdata is None:
+                    xdata = None
+                    #if dataset_plotconfig.axvline:
+                    #    xdata = dataset_plotconfig.axvline_x
+                    #elif dataset_plotconfig.axhline:
+                    #    pass
+                    if header_xvar is not None:
+                        if dataset.dataformat in ('textlog', 'txtlog'):
+                            xdata = dataset.data[split_replace(header_xvar)]
+                        else:
+                            xdata = \
+                                dataset.data[:, dataset.headers.index(
+                                    header_xvar)]
+                    else:
+                        xdata = np.arange(0, len(dataset.ydata))
+
+                    dataset.xdata = xdata
+        #else:
+        #    for dataset_id, dataset in self._flattened_datasets.iteritems():
+        #        dataset_plotconfig = \
+        #            getattr(self._plotconfig.datasets, dataset_id)
+        #        ydata = None
+        #        if dataset_plotconfig.axhline:
+        #            ydata = dataset_plotconfig.axhline_y
+        #        elif dataset_plotconfig.axvline:
+        #            pass
+
+        #        dataset.ydata = ydata
+
+        #        xdata = None
+        #        if dataset_plotconfig.axvline:
+        #            xdata = dataset_plotconfig.axvline_x
+        #        elif dataset_plotconfig.axhline:
+        #            pass
+
+        #        dataset.xdata = xdata
+
     def _validate(self):
         if self._cfgspec is not None:
             validator = Validator()
             validated = self._configobj.validate(validator)
             if not validated:
                 raise PlotConfigParserError('plotcfg failed validation')
+            extra_values = get_extra_values(self._configobj)
+            print('extra_values: {}'.format(extra_values))
 
 
 class XYPlotConfigParser(PlotConfigParser):
@@ -432,5 +540,7 @@ class XYPlotConfigParser(PlotConfigParser):
             fname = 'plot'
         if self._plotconfig.output.fname_prefix is not None:
             fname = self._plotconfig.output.fname_prefix + '_' + fname
+        if self._plotconfig.output.fname_suffix is not None:
+            fname += self._plotconfig.output.fname_suffix
 
         return fname
