@@ -229,7 +229,7 @@ def get_mpl_rcParams(mplobj, profile=None, usetex=False,
         mplobj.rcParams['legend.handlelength'] = 1.25
         mplobj.rcParams['legend.handleheight'] = 1.0
         mplobj.rcParams['legend.handletextpad'] = 0.25
-        mplobj.rcParams['legend.borderaxespad'] = 0.125
+        mplobj.rcParams['legend.borderaxespad'] = 0.5
         mplobj.rcParams['axes.linewidth'] = 1
         mplobj.rcParams['lines.linewidth'] = 1.5
         mplobj.rcParams['lines.markersize'] = 4.0
@@ -251,6 +251,82 @@ def get_mpl_rcParams(mplobj, profile=None, usetex=False,
         mplobj.rcParams['ytick.major.pad'] = 2.5
         mplobj.rcParams['ytick.minor.pad'] = 2.5
 
+    elif profile == 'kgraph-wide':
+
+        figkwargs['xdim'] = 12
+        figkwargs['ydim'] = 3
+
+        figkwargs['cbar.label.fontsize'] = 7
+        figkwargs['contour.label.fontsize'] = 10
+        figkwargs['annotation.fontsize'] = 6
+        figkwargs['tiny.annotation.fontsize'] = 4
+        figkwargs['text.fontsize'] = 2.5
+        figkwargs['tiny.text.fontsize'] = 1.5
+        figkwargs['marker.scale.factor'] = 0.3
+        figkwargs['labelpad'] = 4
+        figkwargs['legend.marker.scale.factor'] = 1.0
+        figkwargs['legend.fontsize'] = 10.5
+        figkwargs['title.fontsize'] = 10
+        figkwargs['dropshadow.offset.x'] = 1.5
+        figkwargs['dropshadow.offset.y'] = -3
+        figkwargs['text.label.fontsize'] = 10
+
+        figkwargs['tick.major.size'] = 6
+        figkwargs['tick.minor.size'] = 3
+
+        figkwargs['tick.width'] = 1
+        figkwargs['tick.major.width'] = figkwargs['tick.width']
+        figkwargs['tick.minor.width'] = figkwargs['tick.width']
+
+        figkwargs['inset.axes.linewidth'] = 1
+        figkwargs['inset.axes.markersize'] = 4
+        figkwargs['inset.axes.marker.scale.factor'] = 0.25
+        figkwargs['inset.axes.fontsize'] = 6
+        figkwargs['inset.axes.labelsize'] = 7
+        figkwargs['inset.axes.labelpad'] = 0.5
+        figkwargs['inset.axes.legend.fontsize'] = 4
+        figkwargs['inset.axes.annotation.fontsize'] = 6
+        figkwargs['inset.axes.tiny.annotation.fontsize'] = 1.5
+        figkwargs['inset.axes.text.fontsize'] = 2
+        figkwargs['inset.axes.tiny.text.fontsize'] = 1.5
+        figkwargs['inset.axes.tick.major.size'] = 3
+        figkwargs['inset.axes.tick.minor.size'] = 1.5
+        figkwargs['inset.axes.tick.width'] = 0.5
+        figkwargs['inset.axes.tick.labelsize'] = 5
+        figkwargs['inset.axes.tick.labelpad'] = 0.15
+
+        mplobj.rcParams['font.size'] = 16
+        mplobj.rcParams['axes.labelsize'] = 18
+        mplobj.rcParams['legend.fontsize'] = 16
+
+        mplobj.rcParams['legend.borderpad'] = 0.5
+        mplobj.rcParams['legend.markerscale'] = 1.0
+        mplobj.rcParams['legend.labelspacing'] = 0.25
+        mplobj.rcParams['legend.handlelength'] = 1.25
+        mplobj.rcParams['legend.handleheight'] = 1.0
+        mplobj.rcParams['legend.handletextpad'] = 0.25
+        mplobj.rcParams['legend.borderaxespad'] = 0.125
+        mplobj.rcParams['axes.linewidth'] = 2
+        mplobj.rcParams['lines.linewidth'] = 3
+        mplobj.rcParams['lines.markersize'] = 4.0
+        mplobj.rcParams['lines.markeredgewidth'] = 0.75
+
+        mplobj.rcParams['xtick.direction'] = 'out'
+        mplobj.rcParams['xtick.major.size'] = 7
+        mplobj.rcParams['xtick.minor.size'] = 4
+        mplobj.rcParams['xtick.major.width'] = 2
+        mplobj.rcParams['xtick.minor.width'] = 2
+        mplobj.rcParams['xtick.major.pad'] = 4
+        mplobj.rcParams['xtick.minor.pad'] = 4
+
+        mplobj.rcParams['ytick.direction'] = 'out'
+        mplobj.rcParams['ytick.major.size'] = 7
+        mplobj.rcParams['ytick.minor.size'] = 4
+        mplobj.rcParams['ytick.major.width'] = 2
+        mplobj.rcParams['ytick.minor.width'] = 2
+        mplobj.rcParams['ytick.major.pad'] = 4
+        mplobj.rcParams['ytick.minor.pad'] = 4
+
     elif profile == 'paper':
 
         figkwargs['xdim'] = figkwargs['ydim'] = 4
